import { z } from 'zod';
export declare const acs_credential_external_type: z.ZodEnum<["pti_card", "brivo_credential", "hid_credential", "visionline_card", "salto_ks_credential"]>;
export declare const acs_credential_access_method_type: z.ZodEnum<["code", "card", "mobile_key"]>;
export type AcsCredentialExternalType = z.infer<typeof acs_credential_external_type>;
export declare const acs_credential: z.ZodObject<z.objectUtil.extendShape<{
    acs_credential_id: z.ZodString;
    acs_user_id: z.ZodOptional<z.ZodString>;
    acs_credential_pool_id: z.ZodOptional<z.ZodString>;
    acs_system_id: z.ZodString;
    parent_acs_credential_id: z.ZodOptional<z.ZodString>;
    display_name: z.ZodString;
    code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    card_number: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    is_issued: z.ZodOptional<z.ZodBoolean>;
    issued_at: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    access_method: z.ZodEnum<["code", "card", "mobile_key"]>;
    external_type: z.ZodOptional<z.ZodEnum<["pti_card", "brivo_credential", "hid_credential", "visionline_card", "salto_ks_credential"]>>;
    external_type_display_name: z.ZodOptional<z.ZodString>;
    created_at: z.ZodString;
    workspace_id: z.ZodString;
    starts_at: z.ZodOptional<z.ZodString>;
    ends_at: z.ZodOptional<z.ZodString>;
    errors: z.ZodArray<z.ZodObject<{
        error_code: z.ZodString;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        error_code: string;
    }, {
        message: string;
        error_code: string;
    }>, "many">;
    warnings: z.ZodArray<z.ZodObject<{
        warning_code: z.ZodString;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        warning_code: string;
    }, {
        message: string;
        warning_code: string;
    }>, "many">;
    is_multi_phone_sync_credential: z.ZodOptional<z.ZodBoolean>;
    is_latest_desired_state_synced_with_provider: z.ZodOptional<z.ZodBoolean>;
    latest_desired_state_synced_with_provider_at: z.ZodOptional<z.ZodString>;
    visionline_metadata: z.ZodOptional<z.ZodObject<{
        card_function_type: z.ZodEnum<["guest", "staff"]>;
        joiner_acs_credential_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        guest_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        common_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        is_valid: z.ZodOptional<z.ZodBoolean>;
        auto_join: z.ZodOptional<z.ZodBoolean>;
        card_id: z.ZodOptional<z.ZodString>;
        credential_id: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    }, {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    }>>;
}, {
    is_managed: z.ZodLiteral<true>;
}>, "strip", z.ZodTypeAny, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    warnings: {
        message: string;
        warning_code: string;
    }[];
    display_name: string;
    workspace_id: string;
    is_managed: true;
    acs_system_id: string;
    acs_credential_id: string;
    access_method: "code" | "card" | "mobile_key";
    code?: string | null | undefined;
    starts_at?: string | undefined;
    ends_at?: string | undefined;
    visionline_metadata?: {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    } | undefined;
    external_type?: "pti_card" | "brivo_credential" | "hid_credential" | "visionline_card" | "salto_ks_credential" | undefined;
    external_type_display_name?: string | undefined;
    acs_user_id?: string | undefined;
    acs_credential_pool_id?: string | undefined;
    parent_acs_credential_id?: string | undefined;
    card_number?: string | null | undefined;
    is_issued?: boolean | undefined;
    issued_at?: string | null | undefined;
    is_multi_phone_sync_credential?: boolean | undefined;
    is_latest_desired_state_synced_with_provider?: boolean | undefined;
    latest_desired_state_synced_with_provider_at?: string | undefined;
}, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    warnings: {
        message: string;
        warning_code: string;
    }[];
    display_name: string;
    workspace_id: string;
    is_managed: true;
    acs_system_id: string;
    acs_credential_id: string;
    access_method: "code" | "card" | "mobile_key";
    code?: string | null | undefined;
    starts_at?: string | undefined;
    ends_at?: string | undefined;
    visionline_metadata?: {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    } | undefined;
    external_type?: "pti_card" | "brivo_credential" | "hid_credential" | "visionline_card" | "salto_ks_credential" | undefined;
    external_type_display_name?: string | undefined;
    acs_user_id?: string | undefined;
    acs_credential_pool_id?: string | undefined;
    parent_acs_credential_id?: string | undefined;
    card_number?: string | null | undefined;
    is_issued?: boolean | undefined;
    issued_at?: string | null | undefined;
    is_multi_phone_sync_credential?: boolean | undefined;
    is_latest_desired_state_synced_with_provider?: boolean | undefined;
    latest_desired_state_synced_with_provider_at?: string | undefined;
}>;
export declare const unmanaged_acs_credential: z.ZodObject<z.objectUtil.extendShape<{
    acs_credential_id: z.ZodString;
    acs_user_id: z.ZodOptional<z.ZodString>;
    acs_credential_pool_id: z.ZodOptional<z.ZodString>;
    acs_system_id: z.ZodString;
    parent_acs_credential_id: z.ZodOptional<z.ZodString>;
    display_name: z.ZodString;
    code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    card_number: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    is_issued: z.ZodOptional<z.ZodBoolean>;
    issued_at: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    access_method: z.ZodEnum<["code", "card", "mobile_key"]>;
    external_type: z.ZodOptional<z.ZodEnum<["pti_card", "brivo_credential", "hid_credential", "visionline_card", "salto_ks_credential"]>>;
    external_type_display_name: z.ZodOptional<z.ZodString>;
    created_at: z.ZodString;
    workspace_id: z.ZodString;
    starts_at: z.ZodOptional<z.ZodString>;
    ends_at: z.ZodOptional<z.ZodString>;
    errors: z.ZodArray<z.ZodObject<{
        error_code: z.ZodString;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        error_code: string;
    }, {
        message: string;
        error_code: string;
    }>, "many">;
    warnings: z.ZodArray<z.ZodObject<{
        warning_code: z.ZodString;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        warning_code: string;
    }, {
        message: string;
        warning_code: string;
    }>, "many">;
    is_multi_phone_sync_credential: z.ZodOptional<z.ZodBoolean>;
    is_latest_desired_state_synced_with_provider: z.ZodOptional<z.ZodBoolean>;
    latest_desired_state_synced_with_provider_at: z.ZodOptional<z.ZodString>;
    visionline_metadata: z.ZodOptional<z.ZodObject<{
        card_function_type: z.ZodEnum<["guest", "staff"]>;
        joiner_acs_credential_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        guest_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        common_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        is_valid: z.ZodOptional<z.ZodBoolean>;
        auto_join: z.ZodOptional<z.ZodBoolean>;
        card_id: z.ZodOptional<z.ZodString>;
        credential_id: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    }, {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    }>>;
}, {
    is_managed: z.ZodLiteral<false>;
}>, "strip", z.ZodTypeAny, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    warnings: {
        message: string;
        warning_code: string;
    }[];
    display_name: string;
    workspace_id: string;
    is_managed: false;
    acs_system_id: string;
    acs_credential_id: string;
    access_method: "code" | "card" | "mobile_key";
    code?: string | null | undefined;
    starts_at?: string | undefined;
    ends_at?: string | undefined;
    visionline_metadata?: {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    } | undefined;
    external_type?: "pti_card" | "brivo_credential" | "hid_credential" | "visionline_card" | "salto_ks_credential" | undefined;
    external_type_display_name?: string | undefined;
    acs_user_id?: string | undefined;
    acs_credential_pool_id?: string | undefined;
    parent_acs_credential_id?: string | undefined;
    card_number?: string | null | undefined;
    is_issued?: boolean | undefined;
    issued_at?: string | null | undefined;
    is_multi_phone_sync_credential?: boolean | undefined;
    is_latest_desired_state_synced_with_provider?: boolean | undefined;
    latest_desired_state_synced_with_provider_at?: string | undefined;
}, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    warnings: {
        message: string;
        warning_code: string;
    }[];
    display_name: string;
    workspace_id: string;
    is_managed: false;
    acs_system_id: string;
    acs_credential_id: string;
    access_method: "code" | "card" | "mobile_key";
    code?: string | null | undefined;
    starts_at?: string | undefined;
    ends_at?: string | undefined;
    visionline_metadata?: {
        card_function_type: "guest" | "staff";
        joiner_acs_credential_ids?: string[] | undefined;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        is_valid?: boolean | undefined;
        auto_join?: boolean | undefined;
        card_id?: string | undefined;
        credential_id?: string | undefined;
    } | undefined;
    external_type?: "pti_card" | "brivo_credential" | "hid_credential" | "visionline_card" | "salto_ks_credential" | undefined;
    external_type_display_name?: string | undefined;
    acs_user_id?: string | undefined;
    acs_credential_pool_id?: string | undefined;
    parent_acs_credential_id?: string | undefined;
    card_number?: string | null | undefined;
    is_issued?: boolean | undefined;
    issued_at?: string | null | undefined;
    is_multi_phone_sync_credential?: boolean | undefined;
    is_latest_desired_state_synced_with_provider?: boolean | undefined;
    latest_desired_state_synced_with_provider_at?: string | undefined;
}>;
export declare const acs_credential_on_encoder: z.ZodObject<{
    created_at: z.ZodNullable<z.ZodString>;
    is_issued: z.ZodNullable<z.ZodBoolean>;
    starts_at: z.ZodNullable<z.ZodString>;
    ends_at: z.ZodNullable<z.ZodString>;
    card_number: z.ZodNullable<z.ZodString>;
    visionline_metadata: z.ZodOptional<z.ZodObject<{
        card_id: z.ZodString;
        cancelled: z.ZodBoolean;
        discarded: z.ZodBoolean;
        expired: z.ZodBoolean;
        overwritten: z.ZodBoolean;
        overridden: z.ZodOptional<z.ZodBoolean>;
        pending_auto_update: z.ZodBoolean;
        card_format: z.ZodEnum<["TLCode", "rfid48"]>;
        card_holder: z.ZodOptional<z.ZodString>;
        number_of_issued_cards: z.ZodNumber;
        guest_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        common_acs_entrance_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        expired: boolean;
        card_id: string;
        cancelled: boolean;
        discarded: boolean;
        overwritten: boolean;
        pending_auto_update: boolean;
        card_format: "TLCode" | "rfid48";
        number_of_issued_cards: number;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        overridden?: boolean | undefined;
        card_holder?: string | undefined;
    }, {
        expired: boolean;
        card_id: string;
        cancelled: boolean;
        discarded: boolean;
        overwritten: boolean;
        pending_auto_update: boolean;
        card_format: "TLCode" | "rfid48";
        number_of_issued_cards: number;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        overridden?: boolean | undefined;
        card_holder?: string | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    created_at: string | null;
    starts_at: string | null;
    ends_at: string | null;
    card_number: string | null;
    is_issued: boolean | null;
    visionline_metadata?: {
        expired: boolean;
        card_id: string;
        cancelled: boolean;
        discarded: boolean;
        overwritten: boolean;
        pending_auto_update: boolean;
        card_format: "TLCode" | "rfid48";
        number_of_issued_cards: number;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        overridden?: boolean | undefined;
        card_holder?: string | undefined;
    } | undefined;
}, {
    created_at: string | null;
    starts_at: string | null;
    ends_at: string | null;
    card_number: string | null;
    is_issued: boolean | null;
    visionline_metadata?: {
        expired: boolean;
        card_id: string;
        cancelled: boolean;
        discarded: boolean;
        overwritten: boolean;
        pending_auto_update: boolean;
        card_format: "TLCode" | "rfid48";
        number_of_issued_cards: number;
        guest_acs_entrance_ids?: string[] | undefined;
        common_acs_entrance_ids?: string[] | undefined;
        overridden?: boolean | undefined;
        card_holder?: string | undefined;
    } | undefined;
}>;
export type AcsCredential = z.output<typeof acs_credential>;
export type UnmanagedAcsCredential = z.output<typeof unmanaged_acs_credential>;
export type AcsCredentialOnEncoder = z.output<typeof acs_credential_on_encoder>;
