import { z } from 'zod';
export declare const acs_entrance: z.ZodObject<{
    acs_system_id: z.ZodString;
    acs_entrance_id: z.ZodString;
    created_at: z.ZodString;
    display_name: z.ZodString;
    errors: z.ZodArray<z.ZodObject<{
        error_code: z.ZodString;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        error_code: string;
    }, {
        message: string;
        error_code: string;
    }>, "many">;
    latch_metadata: z.ZodOptional<z.ZodObject<{
        accessibility_type: z.ZodString;
        door_name: z.ZodString;
        door_type: z.ZodString;
        is_connected: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        door_name: string;
        is_connected: boolean;
        door_type: string;
        accessibility_type: string;
    }, {
        door_name: string;
        is_connected: boolean;
        door_type: string;
        accessibility_type: string;
    }>>;
    visionline_metadata: z.ZodOptional<z.ZodObject<{
        door_name: z.ZodString;
        door_category: z.ZodEnum<["entrance", "guest", "elevator reader", "common", "common (PMS)"]>;
        profiles: z.ZodOptional<z.ZodArray<z.ZodObject<{
            visionline_door_profile_id: z.ZodString;
            visionline_door_profile_type: z.ZodEnum<["BLE", "commonDoor", "touch"]>;
        }, "strip", z.ZodTypeAny, {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }, {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        door_name: string;
        door_category: "entrance" | "guest" | "elevator reader" | "common" | "common (PMS)";
        profiles?: {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }[] | undefined;
    }, {
        door_name: string;
        door_category: "entrance" | "guest" | "elevator reader" | "common" | "common (PMS)";
        profiles?: {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }[] | undefined;
    }>>;
    salto_ks_metadata: z.ZodOptional<z.ZodObject<{
        door_name: z.ZodString;
        locked_state: z.ZodString;
        lock_type: z.ZodString;
        online: z.ZodBoolean;
        battery_level: z.ZodString;
        left_open_alarm: z.ZodBoolean;
        intrusion_alarm: z.ZodBoolean;
        privacy_mode: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        online: boolean;
        lock_type: string;
        battery_level: string;
        locked_state: string;
        door_name: string;
        left_open_alarm: boolean;
        intrusion_alarm: boolean;
        privacy_mode: boolean;
    }, {
        online: boolean;
        lock_type: string;
        battery_level: string;
        locked_state: string;
        door_name: string;
        left_open_alarm: boolean;
        intrusion_alarm: boolean;
        privacy_mode: boolean;
    }>>;
    dormakaba_community_metadata: z.ZodOptional<z.ZodObject<{
        access_point_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        access_point_name: string;
    }, {
        access_point_name: string;
    }>>;
    assa_abloy_vostio_metadata: z.ZodOptional<z.ZodObject<{
        door_type: z.ZodEnum<["CommonDoor", "EntranceDoor", "GuestDoor", "Elevator"]>;
        door_name: z.ZodString;
        door_number: z.ZodOptional<z.ZodNumber>;
        stand_open: z.ZodOptional<z.ZodBoolean>;
        pms_id: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        door_name: string;
        door_type: "CommonDoor" | "EntranceDoor" | "GuestDoor" | "Elevator";
        door_number?: number | undefined;
        stand_open?: boolean | undefined;
        pms_id?: string | undefined;
    }, {
        door_name: string;
        door_type: "CommonDoor" | "EntranceDoor" | "GuestDoor" | "Elevator";
        door_number?: number | undefined;
        stand_open?: boolean | undefined;
        pms_id?: string | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    display_name: string;
    acs_system_id: string;
    acs_entrance_id: string;
    salto_ks_metadata?: {
        online: boolean;
        lock_type: string;
        battery_level: string;
        locked_state: string;
        door_name: string;
        left_open_alarm: boolean;
        intrusion_alarm: boolean;
        privacy_mode: boolean;
    } | undefined;
    visionline_metadata?: {
        door_name: string;
        door_category: "entrance" | "guest" | "elevator reader" | "common" | "common (PMS)";
        profiles?: {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }[] | undefined;
    } | undefined;
    assa_abloy_vostio_metadata?: {
        door_name: string;
        door_type: "CommonDoor" | "EntranceDoor" | "GuestDoor" | "Elevator";
        door_number?: number | undefined;
        stand_open?: boolean | undefined;
        pms_id?: string | undefined;
    } | undefined;
    latch_metadata?: {
        door_name: string;
        is_connected: boolean;
        door_type: string;
        accessibility_type: string;
    } | undefined;
    dormakaba_community_metadata?: {
        access_point_name: string;
    } | undefined;
}, {
    created_at: string;
    errors: {
        message: string;
        error_code: string;
    }[];
    display_name: string;
    acs_system_id: string;
    acs_entrance_id: string;
    salto_ks_metadata?: {
        online: boolean;
        lock_type: string;
        battery_level: string;
        locked_state: string;
        door_name: string;
        left_open_alarm: boolean;
        intrusion_alarm: boolean;
        privacy_mode: boolean;
    } | undefined;
    visionline_metadata?: {
        door_name: string;
        door_category: "entrance" | "guest" | "elevator reader" | "common" | "common (PMS)";
        profiles?: {
            visionline_door_profile_id: string;
            visionline_door_profile_type: "BLE" | "commonDoor" | "touch";
        }[] | undefined;
    } | undefined;
    assa_abloy_vostio_metadata?: {
        door_name: string;
        door_type: "CommonDoor" | "EntranceDoor" | "GuestDoor" | "Elevator";
        door_number?: number | undefined;
        stand_open?: boolean | undefined;
        pms_id?: string | undefined;
    } | undefined;
    latch_metadata?: {
        door_name: string;
        is_connected: boolean;
        door_type: string;
        accessibility_type: string;
    } | undefined;
    dormakaba_community_metadata?: {
        access_point_name: string;
    } | undefined;
}>;
export type AcsEntrance = z.infer<typeof acs_entrance>;
